@@ -26,6 +26,14 @@
 
 ![projen-cdk-tutorial-part-1](https://projen-cdk-tutorial.s3.amazonaws.com/projen-cdk-tutorial-part-1.png)
 
+![projen-cdk-tutorial-part-1-build](https://projen-cdk-tutorial.s3.amazonaws.com/projen-cdk-tutorial-part-1-build.PNG)
+
+![projen-cdk-tutorial-part-1-release](https://projen-cdk-tutorial.s3.amazonaws.com/projen-cdk-tutorial-part-1-release.PNG)
+
+## License
+
+The [Apache-2.0](https://github.com/AymanZahran/projen-cdk-tutorial-part-1/blob/master/LICENSE) license
+
 ## References
 
 * [CDK Getting Started](https://docs.aws.amazon.com/cdk/v2/guide/getting_started.html)
@@ -33,6 +41,7 @@
 * [CDK Workshop](https://cdkworkshop.com/)
 * [CDK Patterns](https://cdkpatterns.com/)
 * [CDK Construct Hub](https://constructs.dev/)
+* [AWS Solutions Constructs](https://docs.aws.amazon.com/solutions/latest/constructs/welcome.html)
 * [Projen](https://github.com/projen/projen)
 * [Projen API Reference](https://projen.io/api/API.html)
 * [Projen AWS CDK Construct Library](https://projen.io/awscdk-construct.html)
